{{- define "storage_cache.env" }}
{{- if eq (index .Values .serviceName).storageProvider "minio" }}
- name: SPRING_PROFILES_ACTIVE
  value: "cnc-minio"
- name: MINIO_HOST
  value: {{ required "A valid Minio hostname entry required." (index .Values .serviceName).minio.host | quote}}
- name: MINIO_PORT
  value: {{ (index .Values .serviceName).minio.port | quote}}
- name: MINIO_ACCESS_KEY
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).minio.secret | quote }}
      key: root-user
      optional: false
- name: MINIO_SECRET_KEY
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).minio.secret | quote }}
      key: root-password
      optional: false
- name: MINIO_SECURE
  value: {{ (index .Values .serviceName).minio.secure | quote}}
- name: MINIO_CACERT
  value: {{ (index .Values .serviceName).minio.cacert | quote}}
- name: MINIO_VERIFY_HOSTNAME
  value: {{ (index .Values .serviceName).minio.verifyHostName | quote}}
{{- end }}
{{- if eq (index .Values .serviceName).storageProvider "aws" }}
- name: SPRING_PROFILES_ACTIVE
  value: "cnc-aws"
- name: AWS_REGION
  value: {{ required "A valid AWS region entry required." (index .Values .serviceName).aws.region | quote}}
- name: AWS_ACCESS_KEY_ID
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).aws.secret | quote }}
      key: aws_access_key
      optional: false
- name: AWS_SECRET_ACCESS_KEY
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).aws.secret | quote }}
      key: aws_secret_key
      optional: false
{{- end}}
{{- if eq (index .Values .serviceName).storageProvider "gcp" }}
- name: SPRING_PROFILES_ACTIVE
  value: "cnc-gcp"
- name: GOOGLE_CLOUD_PROJECT
  value: {{ required "A valid GCP projectname entry required." (index .Values .serviceName).gcp.project | quote}}
- name: GOOGLE_APPLICATION_CREDENTIALS
  value: /etc/gcp/key.json
{{- end}}
{{- if eq (index .Values .serviceName).storageProvider "azure" }}
- name: SPRING_PROFILES_ACTIVE
  value: "cnc-azure"
- name: AZURE_ENDPOINT
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).azure.secret | quote }}
      key: azure_endpoint
      optional: false
- name: AZURE_TENANT_ID
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).azure.secret | quote }}
      key: azure_tenant_id
      optional: false
- name: AZURE_CLIENT_ID
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).azure.secret | quote }}
      key: azure_client_id
      optional: false
- name: AZURE_CLIENT_SECRET
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).azure.secret | quote }}
      key: azure_client_secret
      optional: false
- name: AZURE_SUBSCRIPTION_ID
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).azure.secret | quote }}
      key: azure_subscription_id
      optional: false
- name: AZURE_RESOURCE_GROUP
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).azure.secret | quote }}
      key: azure_resource_group
      optional: false
{{- end}}
{{- end }}

{{- define "redis_cache.env" }}
- name: REDIS_HOST
  value: {{ required "A valid redis hostname entry required." (index .Values .serviceName).redis.host | quote}}
- name: REDIS_PORT
  value: {{ (index .Values .serviceName).redis.port | quote}}
- name: REDIS_DATABASE
  value: {{ (index .Values .serviceName).redis.database | quote}}
- name: REDIS_PASSWORD
  {{- if (index .Values .serviceName).redis.authEnabled }}
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).redis.passwordSecret | quote }}
      key: password
      optional: false
  {{- else }}
  value: ""
  {{- end}}
- name: REDIS_SECURE
  value: {{ (index .Values .serviceName).redis.secure | quote}}
- name: REDIS_CACERT
{{- if (index .Values .serviceName).redis.cacertSecret}}
  value: /etc/redis/ssl/ca.crt
{{- else }}
  value: ""
{{- end}}
- name: REDIS_VERIFY_HOSTNAME
  value: {{ (index .Values .serviceName).redis.verifyHostName | quote}}
{{- end }}